import { useState, useEffect } from "react";
import Taro, { useDidShow } from "@tarojs/taro";
import { useSelector } from "react-redux";
import withLayout from "@/layout";
import { querybkBankCard } from "@/services/broker";
import { ScrollView, Input, Image, Block, Textarea } from "@tarojs/components";
import { getImgURL } from "@/utils/image";
import { fetch, uploadFiles } from "@/utils/request";
import { UPDATE_USER_INFO, ROLE_CODE } from "@/constants/user";
import { queryBrokerRankMine } from "@/services/broker";
import WalletList from "./list";

import "@/assets/css/iconfont.css";
import "./index.scss";

export default withLayout((props) => {
  const { person } = props;
  const [activeKey, setActiveKey] = useState(1);
  const [mineInfo, setMineInfo] = useState({});

  useEffect(() => {
    queryBrokerRankMine().then((res) => {
      setMineInfo(res);
    });
  }, []);

  useDidShow(() => {
    if (!person.idNo) {
      Taro.showModal({
        title: "完善信息",
        content: "请提供您的身份证信息",
        success: (res) => {
          if (res.confirm) {
            Taro.navigateTo({
              url: "/subpackages/pages/broker/toBeBroker/index",
            });
          } else if (res.cancel) {
            Taro.navigateBack({ delta: 1 });
          }
        },
      });

      return;
    }
    querybkBankCard().then((res) => {
      if (res.total === 0) {
        Taro.showModal({
          title: "完善信息",
          content: "请提供您的银行卡信息",
          success: (res) => {
            if (res.confirm) {
              Taro.navigateTo({
                url: "/subpackages/pages/broker/toBeBroker/index",
              });
            } else if (res.cancel) {
              Taro.navigateBack({ delta: 1 });
            }
          },
        });
      }
    });
  });

  return (
    <view className="Page myWallet">
      <view className="top">
        <view className="tabs">
          <view
            className={`tab ${activeKey === 1 ? "active" : ""}`}
            onClick={() => setActiveKey(1)}
          >
            我的佣金
          </view>
          <view
            className={`tab ${activeKey === 2 ? "active" : ""}`}
            onClick={() => setActiveKey(2)}
          >
            我的奖励
          </view>
        </view>
      </view>
      <view className="middle">
        <text className="text1">总资产（元）</text>
        <text className="text2">
          {Number(
            (activeKey === 1
              ? mineInfo.totalCommission || 0
              : mineInfo.referralFee || 0) / 100
          ).toFixed(2)}
        </text>
      </view>
      <view className="bottom">
        <WalletList show={activeKey === 1} type={"commission"}></WalletList>
        <WalletList show={activeKey === 2} type={"reward"}></WalletList>
      </view>
    </view>
  );
});
