import { useState, useEffect } from "react";
import Taro from "@tarojs/taro";
import { useSelector } from "react-redux";
import withLayout from "@/layout";
import { ScrollView, Input, Image, Block, Textarea } from "@tarojs/components";
import { getImgURL } from "@/utils/image";
import { queryBrokerRank } from "@/services/broker";
import MyAchievement from "../components/myAchievement";
import AchievementList from "../components/list";
import store from "@/store";

import "@/assets/css/iconfont.css";
import "./index.scss";

export default withLayout((props) => {
  const {myRank} = props
  const columns = [
    {
      title: "排名",
      width: "20%",
      dataIndex: "a",
      myRankRender:'*',
      render: (x, index) => {
        if (index >= 3) {
          return index + 1;
        } else {
          return (
            <image
              className="rank-image"
              src={`${OSS_FAST_PATH}/miniapp/broker/${index + 1}.png`}
              alt=""
              srcset=""
            />
          );
        }
      },
    },
    {
      title: "姓名",
      width: "30%",
      dataIndex: "name",
      myRankRender: <view>
      <image
        className="list-image"
        src={myRank.avatarurl}
        alt=""
        srcset=""
      />
      {myRank.name}
    </view>,
      render: (x) => (
        <view>
          <image
            className="list-image"
            src={x.avatarurl}
            alt=""
            srcset=""
          />
          {x.name}
        </view>
      ),
    },
    {
      title: "数量（组）",
      width: "25%",
      dataIndex: "customerNum",
      myRankRender:`${myRank.customerNum||0}组`,
    },
    {
      title: "佣金（元）",
      width: "25%",
      dataIndex: "totalCommission",
      render: (x) => (
        `${Number((x.totalCommission || 0) / 100).toFixed(2)}元`
      ),
  
      myRankRender:`${Number((myRank.totalCommission || 0) / 100).toFixed(2)}元`
    },
  ];

 

  return (
    <view className="invitationList">
      <MyAchievement
        columns={columns}
        data={{...myRank,a:'*'}}
      />
      <AchievementList
        columns={columns}
        params={{ rankType: "money" }}
        getList={queryBrokerRank}
      />
    </view>
  );
});
